@@ -9,18 +9,18 @@ from provider import DanbooruProvider, GelbooruProvider
 
 class BooruPy:
 
-    def __init__(self, providerlist_path):
+    def __init__(self, providerlist_path, filter_nsfw=True):
         providers = json.load(open(providerlist_path))
         self.provider_list = []
         for p in providers:
             if p["type"] == "danbooru":
                 self.provider_list.append(DanbooruProvider(p['url'], p['name'],
-                    p['key']))
+                    p['key'], filter_nsfw))
             elif p["type"] == "gelbooru":
-                self.provider_list.append(GelbooruProvider(p['url'],
-                    p['name'], p['key']))
+                self.provider_list.append(GelbooruProvider(p['url'], p['name'],
+                    p['key'], filter_nsfw))
             else:
-                pass  # TODO: raise error
+                print("Unknown provider type: {0}".format(p["type"]))
 
     def get_provider_by_id(self, provider_id):
         if isinstance(provider_id, int):
